==> customer-js-sdk-1.13.0.tgz: package/src/v0/src/modules/affiliation/bankAccounts/bankAccounts.test.js <==
import sinon from 'sinon';
import { service as bankAccountsService } from './bankAccounts.js';
import { bankAccountsInterface } from './bankAccountsInterface.js';

const urlParams = {
  affiliationCode: '321321321',
  key: 1,
};

describe('Bank Accounts Module', () => {
  it('Should have methods after initialization.', () => {
    const service = bankAccountsService();
    expect(service.get).to.be.a('function');
    expect(service.patch).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = bankAccountsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = bankAccountsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(
      'v0/affiliation/merchants/321321321/bank-accounts');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = bankAccountsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });

  it('Should call patch request.', () => {
    const spy = sinon.spy();

    const patchRequest = () => spy;

    const service = bankAccountsService(undefined, patchRequest);

    service.patch(urlParams, bankAccountsInterface);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call patch request and return a valid URL.', () => {
    const spy = sinon.spy();

    const patchRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = bankAccountsService(undefined, patchRequest);

    service.patch(urlParams, bankAccountsInterface);

    expect(spy).to.have.been
      .calledWith('v0/affiliation/merchants/321321321/bank-accounts/1');
  });

  it('Should call patch request with valid params.', () => {
    const spy = sinon.spy();

    const patchRequest = () => spy;

    const service = bankAccountsService(undefined, patchRequest);

    service.patch(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});

==> customer-js-sdk-1.34.0.tgz: package/src/v0/src/modules/affiliation/bankAccounts/bankAccounts.test.js <==
import sinon from 'sinon';
import { service as bankAccountsService } from './bankAccounts.js';
import { bankAccountsInterface } from './bankAccountsInterface.js';

const urlParams = {
  affiliationCode: '321321321',
  key: 1,
};

describe('Bank Accounts Module', () => {
  it('Should have methods after initialization.', () => {
    const service = bankAccountsService();
    expect(service.get).to.be.a('function');
    expect(service.put).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = bankAccountsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = bankAccountsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(
      'v0/affiliation/merchants/321321321/bankaccounts');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = bankAccountsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });

  it('Should call put request.', () => {
    const spy = sinon.spy();

    const putRequest = () => spy;

    const service = bankAccountsService(undefined, putRequest);

    service.put(urlParams, bankAccountsInterface);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call put request and return a valid URL.', () => {
    const spy = sinon.spy();

    const putRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = bankAccountsService(undefined, putRequest);

    service.put(urlParams, bankAccountsInterface);

    expect(spy).to.have.been
      .calledWith('v0/affiliation/merchants/321321321/bankaccounts/1');
  });

  it('Should call put request with valid params.', () => {
    const spy = sinon.spy();

    const putRequest = () => spy;

    const service = bankAccountsService(undefined, putRequest);

    service.put(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});
